# kafkian
An opinionated Kafka producer/consumer built on top of confluent-kafka-python/librdkafka

[![Build Status](https://travis-ci.org/saabeilin/kafkian.svg?branch=master)](https://travis-ci.org/saabeilin/kafkian)

